@@ -95,7 +95,7 @@ class Magma(object):
         
         In effect return the yaml data with the magic header.
         
-        @return: A human readable representation of the yaml file."""
+        @return: A human readable representation of the Magma file in yaml format (String)."""
         return "#MAGMAv0.4" + "\n" + self.get_yaml_data()
         
     def create_magma_from_files(self, file_paths): 
@@ -117,7 +117,7 @@ class Magma(object):
         @type yaml_data: String
         @return: True or False
         """
-        return yaml_data[:len(MAGMA_0_4_HEADER)] == MAGMA_0_4_HEADER, 
+        return yaml_data[:len(MAGMA_0_4_HEADER)] == MAGMA_0_4_HEADER
     
     def readout_yaml(self, yaml_data):
         """Readout a magma list from data in yaml format.
@@ -131,7 +131,7 @@ class Magma(object):
         # Now readout the data via yaml and return it. 
         data = load(yaml_data)
         # yaml returns None, if nothing is avaible. We need an empty dict though, if the Magma file was empty. 
-        if data is None: 
+        if data is None:
             data = {}
         return data
     
@@ -286,7 +286,7 @@ class MagmaFile(object):
 
 
 def usage(): 
-    """Print usage instructions.
+    """Usage instructions.
     
     @return: Usage instructions (String)."""
     # Just use the docstring. 
